==> 0.0.1%2B1.tar.gz: lib/models/IR5Station.dart <==
import 'package:json_annotation/json_annotation.dart';

part 'IR5Station.g.dart';

// --------------------------------------------------------------------------------

enum SalleOngletsPos { SalleOngletsHided, SalleOngletsTop, SalleOngletsBottom, SalleOngletsLeft, SalleOngletsRight }
const Map<int, SalleOngletsPos> SalleOngletsPoses = {
  0: SalleOngletsPos.SalleOngletsHided,
  1: SalleOngletsPos.SalleOngletsTop,
  2: SalleOngletsPos.SalleOngletsBottom,
  3: SalleOngletsPos.SalleOngletsLeft,
  4: SalleOngletsPos.SalleOngletsRight,
};
int SalleOngletsPosToJson(SalleOngletsPos f) {
  return SalleOngletsPoses.entries.firstWhere((element) => element.value == f).key;
}
// --------------------------------------------------------------------------------

enum CarteOngletsPos { CarteOngletsBottom, CarteOngletsTop, CarteOngletsLeft, CarteOngletsRight }
const Map<int, CarteOngletsPos> CarteOngletsPoses = {
  0: CarteOngletsPos.CarteOngletsBottom,
  1: CarteOngletsPos.CarteOngletsTop,
  2: CarteOngletsPos.CarteOngletsLeft,
  3: CarteOngletsPos.CarteOngletsRight,
};
int CarteOngletsPosToJson(CarteOngletsPos f) {
  return CarteOngletsPoses.entries.firstWhere((element) => element.value == f).key;
}
// --------------------------------------------------------------------------------

/** STATION aka POS Terminal */
@JsonSerializable()
class IR5Station {
  const IR5Station({
    required this.No,
    required this.Nom,
    required this.Flags,
    required this.FiscalId,
    required this.IPAdresse,
    required this.MacAddress,
    required this.StationType,
    required this.Description,
    required this.TblModePOS,
    required this.Serial_Nr,
    required this.Version,
    required this.OnlySalles,
    required this.SalleOngletsPos,
    required this.OnlyOnglets,
    required this.CarteOngletsPos,
    required this.OnlyDivisions,
    required this.TariffIn,
    required this.TariffOut,
    required this.AddLogo,
    this.reg,
  });

  factory IR5Station.fromJson(Map<String, dynamic>? json) => _$IR5StationFromJson(json ?? {});

  Map<String, dynamic> toJson() => _$IR5StationToJson(this);

  /** Station Number */
  @JsonKey(defaultValue: 0)
  final num No;

  /** Station Name */
  @JsonKey(defaultValue: '')
  final String Nom;

  /** Station Flags
   *   Bit 00 : DummyStation
   *   Bit 01 : CleanAtStartUp
   *   Bit 02 : RestomaxTrace
   *   Bit 03 : WMIControl
   *   Bit 04 : NoPrintor
   *   Bit 05 : PrintorTrace
   *   Bit 08 : NoWSServer
   *   Bit 10 : TouchGesture
   *   Bit 12 : HideTaskBar
   *   Bit 13 : CheckPtrs
   *   Bit 14 : ShowPtrs
   *   Bit 15 : ExitNotAllowed
   *   Bit 16 : ShutDown
   *   Bit 19 : RuntimeDesign
   *   Bit 20 : SalleLongClick
   *   Bit 22 : ShowStaffBtn
   *   Bit 23 : ShowHelpInMenuBtn
   *   Bit 24 : ShowPrixInBtn
   *   Bit 25 : CarteLongClick
   *   Bit 30 : UseStationTbl
   *   Bit 31 : IffUseStationTbl
   *   Bit 39 : ForceBackHome
   *   Bit 40 : IsForcedHappyHour
   *   Bit 41 : TarifIN1
   *   Bit 42 : TarifIN2
   *   Bit 43 : TarifIN3
   *   Bit 44 : TarifIN4
   *   Bit 45 : IsForcedFz
   *   Bit 46 : TarifOUT1
   *   Bit 47 : TarifOUT2
   *   Bit 48 : TarifOUT3
   *   Bit 49 : TarifOUT4
   *   Bit 50 : IsForcedOut
   *   Bit 51 : IsForcedIn
   *   Bit 52 : AdditionForbidden
   *   Bit 54 : NoEncaisse
   *   Bit 55 : NoQuickCash
   *   Bit 56 : NoCashAutoFill
   *   Bit 60 : RptModifFlag1
   *   Bit 61 : RptModifFlag2
   *   Bit 62 : RptModifFlag3
   *   Bit 63 : RptModifFlag4
   */
  @JsonKey(defaultValue: 0)
  final num Flags;

  /** Station Serial Identification {A|B}XXXCCCNNNNNNN
   * as required by fiscal administration
   */
  @JsonKey(defaultValue: '')
  final String FiscalId;

  /** Human readeable IPv4 or IPv6 Address */
  @JsonKey(defaultValue: '')
  final String IPAdresse;

  /** MAC_ADDRESS stored as String ex:7E:AF:00:0A:56:07 */
  @JsonKey(defaultValue: '')
  final String MacAddress;

  /** Station Type
   * B : Bureau ( special Cloture Service Handling : no mail, ...)
   * P : Pocket
   * S : Station
   */
  @JsonKey(defaultValue: '')
  final String StationType;

  /** Just a free Description */
  @JsonKey(defaultValue: '')
  final String Description;

  /** Table
   * Default NumTable for mode Pos (Direct Pointing)
   * - Station Number OR
   * - "V"+Staff Number OR
   * - "VG"+Staff Number OR
   * - "VS"+Station Number
   */
  @JsonKey(defaultValue: '')
  final String TblModePOS;

  /** Serial Number used in Reparator */
  @JsonKey(defaultValue: '')
  final String Serial_Nr;

  /** Restomax Exe Version 4.yy.mm.dd */
  @JsonKey(defaultValue: '')
  final String Version;

  /** Accessible Room(s) for the Station,Staff,... */
  @JsonKey(defaultValue: '')
  final String OnlySalles;
  @JsonKey(defaultValue: 0)
  final num /* Number | SalleOngletsPos */ SalleOngletsPos;

  /** Visible Tab(s) for the Station,Staff,... */
  @JsonKey(defaultValue: '')
  final String OnlyOnglets;
  @JsonKey(defaultValue: 0)
  final num /* Number | CarteOngletsPos */ CarteOngletsPos;

  /** Accessible Division(s) for the Station,Staff,Article,.. */
  @JsonKey(defaultValue: '')
  final String OnlyDivisions;

  /** Tariff In. Can be a TblTariff(1,2,3,4) or any TariffColor(Id>999) */

  /** Tariff Color to use if IN(resto) */
  @JsonKey(defaultValue: 1)
  final num TariffIn;

  /** Tariff Out. Can be a TblTariff(1,2,3,4) or any TariffColor(Id>999) */

  /** Tariff Color to use if OUT(emport) */
  @JsonKey(defaultValue: 2)
  final num TariffOut;

  /** Logo to be printed on Addition Ticket */
  @JsonKey(defaultValue: 0)
  final num AddLogo;

  /** Registry values */
  @JsonKey(defaultValue: {})
  final dynamic reg;
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5Station.dart <==
import 'package:json_annotation/json_annotation.dart';

part 'IR5Station.g.dart';

// --------------------------------------------------------------------------------

enum SalleOngletsPos {
  SalleOngletsHided,
  SalleOngletsTop,
  SalleOngletsBottom,
  SalleOngletsLeft,
  SalleOngletsRight
}
const Map<int, SalleOngletsPos> SalleOngletsPoses = {
  0: SalleOngletsPos.SalleOngletsHided,
  1: SalleOngletsPos.SalleOngletsTop,
  2: SalleOngletsPos.SalleOngletsBottom,
  3: SalleOngletsPos.SalleOngletsLeft,
  4: SalleOngletsPos.SalleOngletsRight,
};
int SalleOngletsPosToJson(SalleOngletsPos f) {
  return SalleOngletsPoses.entries
      .firstWhere((element) => element.value == f)
      .key;
}
// --------------------------------------------------------------------------------

enum CarteOngletsPos {
  CarteOngletsBottom,
  CarteOngletsTop,
  CarteOngletsLeft,
  CarteOngletsRight
}
const Map<int, CarteOngletsPos> CarteOngletsPoses = {
  0: CarteOngletsPos.CarteOngletsBottom,
  1: CarteOngletsPos.CarteOngletsTop,
  2: CarteOngletsPos.CarteOngletsLeft,
  3: CarteOngletsPos.CarteOngletsRight,
};
int CarteOngletsPosToJson(CarteOngletsPos f) {
  return CarteOngletsPoses.entries
      .firstWhere((element) => element.value == f)
      .key;
}
// --------------------------------------------------------------------------------

/** STATION aka POS Terminal */
@JsonSerializable()
class IR5Station {
  const IR5Station({
    required this.No,
    required this.Nom,
    required this.Flags,
    required this.FiscalId,
    required this.IPAdresse,
    required this.MacAddress,
    required this.StationType,
    required this.Description,
    required this.TblModePOS,
    required this.Serial_Nr,
    required this.Version,
    required this.OnlySalles,
    required this.SalleOngletsPos,
    required this.OnlyOnglets,
    required this.CarteOngletsPos,
    required this.OnlyDivisions,
    required this.TariffIn,
    required this.TariffOut,
    required this.AddLogo,
    this.reg,
  });

  factory IR5Station.fromJson(Map<String, dynamic>? json) =>
      _$IR5StationFromJson(json ?? {});

  Map<String, dynamic> toJson() => _$IR5StationToJson(this);

  /** Station Number */
  @JsonKey(defaultValue: 0)
  final num No;

  /** Station Name */
  @JsonKey(defaultValue: '')
  final String Nom;

  /** Station Flags
   *   Bit 00 : DummyStation
   *   Bit 01 : CleanAtStartUp
   *   Bit 02 : RestomaxTrace
   *   Bit 03 : WMIControl
   *   Bit 04 : NoPrintor
   *   Bit 05 : PrintorTrace
   *   Bit 08 : NoWSServer
   *   Bit 10 : TouchGesture
   *   Bit 12 : HideTaskBar
   *   Bit 13 : CheckPtrs
   *   Bit 14 : ShowPtrs
   *   Bit 15 : ExitNotAllowed
   *   Bit 16 : ShutDown
   *   Bit 19 : RuntimeDesign
   *   Bit 20 : SalleLongClick
   *   Bit 22 : ShowStaffBtn
   *   Bit 23 : ShowHelpInMenuBtn
   *   Bit 24 : ShowPrixInBtn
   *   Bit 25 : CarteLongClick
   *   Bit 30 : UseStationTbl
   *   Bit 31 : IffUseStationTbl
   *   Bit 39 : ForceBackHome
   *   Bit 40 : IsForcedHappyHour
   *   Bit 41 : TarifIN1
   *   Bit 42 : TarifIN2
   *   Bit 43 : TarifIN3
   *   Bit 44 : TarifIN4
   *   Bit 45 : IsForcedFz
   *   Bit 46 : TarifOUT1
   *   Bit 47 : TarifOUT2
   *   Bit 48 : TarifOUT3
   *   Bit 49 : TarifOUT4
   *   Bit 50 : IsForcedOut
   *   Bit 51 : IsForcedIn
   *   Bit 52 : AdditionForbidden
   *   Bit 54 : NoEncaisse
   *   Bit 55 : NoQuickCash
   *   Bit 56 : NoCashAutoFill
   *   Bit 60 : RptModifFlag1
   *   Bit 61 : RptModifFlag2
   *   Bit 62 : RptModifFlag3
   *   Bit 63 : RptModifFlag4
   */
  @JsonKey(defaultValue: 0)
  final num Flags;

  /** Station Serial Identification {A|B}XXXCCCNNNNNNN
   * as required by fiscal administration
   */
  @JsonKey(defaultValue: '')
  final String FiscalId;

  /** Human readeable IPv4 or IPv6 Address */
  @JsonKey(defaultValue: '')
  final String IPAdresse;

  /** MAC_ADDRESS stored as String ex:7E:AF:00:0A:56:07 */
  @JsonKey(defaultValue: '')
  final String MacAddress;

  /** Station Type
   * B : Bureau ( special Cloture Service Handling : no mail, ...)
   * P : Pocket
   * S : Station
   */
  @JsonKey(defaultValue: '')
  final String StationType;

  /** Just a free Description */
  @JsonKey(defaultValue: '')
  final String Description;

  /** Table
   * Default NumTable for mode Pos (Direct Pointing)
   * - Station Number OR
   * - "V"+Staff Number OR
   * - "VG"+Staff Number OR
   * - "VS"+Station Number
   */
  @JsonKey(defaultValue: '')
  final String TblModePOS;

  /** Serial Number used in Reparator */
  @JsonKey(defaultValue: '')
  final String Serial_Nr;

  /** Restomax Exe Version 4.yy.mm.dd */
  @JsonKey(defaultValue: '')
  final String Version;

  /** Accessible Room(s) for the Station,Staff,... */
  @JsonKey(defaultValue: '')
  final String OnlySalles;
  @JsonKey(defaultValue: 0)
  final num /* Number | SalleOngletsPos */ SalleOngletsPos;

  /** Visible Tab(s) for the Station,Staff,... */
  @JsonKey(defaultValue: '')
  final String OnlyOnglets;
  @JsonKey(defaultValue: 0)
  final num /* Number | CarteOngletsPos */ CarteOngletsPos;

  /** Accessible Division(s) for the Station,Staff,Article,.. */
  @JsonKey(defaultValue: '')
  final String OnlyDivisions;

  /** Tariff In. Can be a TblTariff(1,2,3,4) or any TariffColor(Id>999) */

  /** Tariff Color to use if IN(resto) */
  @JsonKey(defaultValue: 1)
  final num TariffIn;

  /** Tariff Out. Can be a TblTariff(1,2,3,4) or any TariffColor(Id>999) */

  /** Tariff Color to use if OUT(emport) */
  @JsonKey(defaultValue: 2)
  final num TariffOut;

  /** Logo to be printed on Addition Ticket */
  @JsonKey(defaultValue: 0)
  final num AddLogo;

  /** Registry values */
  @JsonKey(defaultValue: {})
  final dynamic reg;
}
